@@ -11,10 +11,10 @@ try:
     from appium.webdriver import WebElement
 except:
     pass
-# try:
-#     from macaca.webdriver import WebElement
-# except:
-#     pass
+try:
+    from macaca.webdriver import WebElement
+except:
+    pass
 
 class Dict(collections.UserDict):
     def __missing__(self, key):
